@@ -5,7 +5,7 @@ from BDMLtools.report import businessReport,EDAReport,varReport,varGroupsReport,
 from BDMLtools.selector import binSelector,binAdjuster,binFreq,binPretty,binTree,binChi2,binKmeans
 from BDMLtools.selector import faSelector
 from BDMLtools.selector import stepLogit,cardScorer
-from BDMLtools.selector import preSelector,corrSelector,prefitModel
+from BDMLtools.selector import preSelector,prefitModel
 #from BDMLtools.selector import RFECVSelector
 from BDMLtools.selector import lassoSelector
 from BDMLtools.plotter import BaseWoePlotter
@@ -15,7 +15,7 @@ from BDMLtools.tuner import girdTuner,hgirdTuner
 from BDMLtools.tuner import BayesianXGBTuner,BayesianLgbmTuner,shapCheck
 
 
-__version__ = '0.1.9.1'
+__version__ = '0.2.0'
 
 __all__ = (    
     dtStandardization,
@@ -41,7 +41,6 @@ __all__ = (
     stepLogit,
     cardScorer,
     preSelector,
-    corrSelector,
     lassoSelector,
     woeTransformer,
     girdTuner,
