@@ -88,14 +88,20 @@ class EDAReport(Base,TransformerMixin):
         else:
             
             num_col=self.numeric_col
+            
+        if len(num_col):
 
-        report=X[num_col].describe(percentiles=[0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9]).T.assign(
-            MissingRate=X.apply(   
-                lambda col:col.isnull().sum()/col.size    
-               )
-        ).reset_index().rename(columns={'index':'VarName'})
+            report=X[num_col].describe(percentiles=[0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9]).T.assign(
+                MissingRate=X.apply(   
+                    lambda col:col.isnull().sum()/col.size    
+                   )
+            ).reset_index().rename(columns={'index':'VarName'})
+            
+            return report
         
-        return report
+        else:
+            
+            return None
     
 
     def _char_info(self,X):
@@ -109,20 +115,26 @@ class EDAReport(Base,TransformerMixin):
         else:
             
             category_col=self.categorical_col
+            
+        if len(category_col):    
     
-        report={}
-        for col in category_col:
-
-            ColTable=X[col].value_counts().sort_index().rename('Freq').reset_index() \
-                .rename(columns={'index':'Levels'})[['Levels','Freq']]
-
-            ColTable['Percent']=ColTable.Freq/X[col].size #占比
-            ColTable['CumFreq']=ColTable.Freq.cumsum() #累计(分类特征类别有次序性时有参考价值)
-            ColTable['CumPercent']=ColTable.CumFreq/X[col].size #累计占比(分类特征类别有次序性时有参考价值)
-
-            report[col]=ColTable
+            report={}
+            for col in category_col:
+    
+                ColTable=X[col].value_counts().sort_index().rename('Freq').reset_index() \
+                    .rename(columns={'index':'Levels'})[['Levels','Freq']]
+    
+                ColTable['Percent']=ColTable.Freq/X[col].size #占比
+                ColTable['CumFreq']=ColTable.Freq.cumsum() #累计(分类特征类别有次序性时有参考价值)
+                ColTable['CumPercent']=ColTable.CumFreq/X[col].size #累计占比(分类特征类别有次序性时有参考价值)
+    
+                report[col]=ColTable
+            
+            return pd.concat(report).droplevel(1).reset_index().rename(columns={'index':'Name'})
         
-        return pd.concat(report).droplevel(1).reset_index().rename(columns={'index':'Name'})
+        else:
+            
+            return None
     
    
     def _nan_info(self,X):
