@@ -11,11 +11,12 @@ from BDMLtools.selector.bin_fun import binFreq,binPretty,binTree,binChi2,binKmea
 from BDMLtools.selector.fa import faSelector
 from BDMLtools.selector.embeded import lassoSelector
 from BDMLtools.selector.logtit import stepLogit,cardScorer
-from BDMLtools.selector.simple import prefitModel,preSelector,corrSelector
+from BDMLtools.selector.simple import prefitModel,preSelector
+from BDMLtools.selector.lgbm import LgbmRFESelector,LgbmSeqSelector
 #from BDMLtools.selector.wrapper import RFECVSelector
 
 
-__all__ = (    
+__all__ = (     
     binSelector,
     binAdjuster,
     binFreq,
@@ -23,12 +24,13 @@ __all__ = (
     binTree,
     binChi2,
     binKmeans,
+    LgbmRFESelector,
+    LgbmSeqSelector,
     faSelector,
     lassoSelector,
     stepLogit,
     cardScorer,
     prefitModel,
-    preSelector,
-    corrSelector
+    preSelector   
 )
 
